@@ -247,6 +247,7 @@ uint64_t siphash(const char *in, const char *k)
 
     return siphash_raw(in, inlen, k);
 }
+
 /** Generate a key that is used by siphash() and siphash_nocase().
  * @param k   The key, this must be a char array of size 16.
  */
@@ -264,8 +265,6 @@ static Channel *channelTable[CHAN_HASH_TABLE_SIZE];
 static char siphashkey_nick[SIPHASH_KEY_LENGTH];
 static char siphashkey_chan[SIPHASH_KEY_LENGTH];
 static char siphashkey_whowas[SIPHASH_KEY_LENGTH];
-static char siphashkey_throttling[SIPHASH_KEY_LENGTH];
-static char siphashkey_ipusers[SIPHASH_KEY_LENGTH];
 
 extern char unreallogo[];
 
@@ -277,8 +276,6 @@ void init_hash(void)
 	siphash_generate_key(siphashkey_nick);
 	siphash_generate_key(siphashkey_chan);
 	siphash_generate_key(siphashkey_whowas);
-	siphash_generate_key(siphashkey_throttling);
-	siphash_generate_key(siphashkey_ipusers);
 
 	for (i = 0; i < NICK_HASH_TABLE_SIZE; i++)
 		INIT_LIST_HEAD(&clientTable[i]);
@@ -288,12 +285,6 @@ void init_hash(void)
 
 	memset(channelTable, 0, sizeof(channelTable));
 
-	memset(ThrottlingHash, 0, sizeof(ThrottlingHash));
-	/* do not call init_throttling() here, as
-	 * config file has not been read yet.
-	 * The hash table is ready, anyway.
-	 */
-
 	if (strcmp(BASE_VERSION, &unreallogo[337]))
 		loop.tainted = 1;
 }
@@ -607,240 +598,3 @@ Client *find_server_by_uid(const char *uid)
 	strlcpy(sid, uid, sizeof(sid));
 	return hash_find_id(sid, NULL);
 }
-
-/* Throttling - originally by Stskeeps */
-
-/* Note that we call this set::anti-flood::connect-flood nowadays */
-
-struct MODVAR ThrottlingBucket *ThrottlingHash[THROTTLING_HASH_TABLE_SIZE];
-
-void update_throttling_timer_settings(void)
-{
-	long v;
-	EventInfo eInfo;
-
-	if (!THROTTLING_PERIOD)
-	{
-		v = 120*1000;
-	} else
-	{
-		v = (THROTTLING_PERIOD*1000)/2;
-		if (v > 5000)
-			v = 5000; /* run at least every 5s */
-		if (v < 1000)
-			v = 1000; /* run at max once every 1s */
-	}
-
-	memset(&eInfo, 0, sizeof(eInfo));
-	eInfo.flags = EMOD_EVERY;
-	eInfo.every_msec = v;
-	EventMod(EventFind("throttling_check_expire"), &eInfo);
-}
-
-uint64_t hash_throttling(const char *ip)
-{
-	return siphash(ip, siphashkey_throttling) % THROTTLING_HASH_TABLE_SIZE;
-}
-
-struct ThrottlingBucket *find_throttling_bucket(Client *client)
-{
-	int hash = 0;
-	struct ThrottlingBucket *p;
-	hash = hash_throttling(client->ip);
-	
-	for (p = ThrottlingHash[hash]; p; p = p->next)
-	{
-		if (!strcmp(p->ip, client->ip))
-			return p;
-	}
-	
-	return NULL;
-}
-
-EVENT(throttling_check_expire)
-{
-	struct ThrottlingBucket *n, *n_next;
-	int	i;
-	static time_t t = 0;
-		
-	for (i = 0; i < THROTTLING_HASH_TABLE_SIZE; i++)
-	{
-		for (n = ThrottlingHash[i]; n; n = n_next)
-		{
-			n_next = n->next;
-			if ((TStime() - n->since) > (THROTTLING_PERIOD ? THROTTLING_PERIOD : 15))
-			{
-				DelListItem(n, ThrottlingHash[i]);
-				safe_free(n->ip);
-				safe_free(n);
-			}
-		}
-	}
-
-	if (!t || (TStime() - t > 30))
-	{
-		extern Module *Modules;
-		char *p = serveropts + strlen(serveropts);
-		Module *mi;
-		t = TStime();
-		if (!Hooks[HOOKTYPE_USERMSG] && strchr(serveropts, 'm'))
-		{ p = strchr(serveropts, 'm'); *p = '\0'; }
-		if (!Hooks[HOOKTYPE_CHANMSG] && strchr(serveropts, 'M'))
-		{ p = strchr(serveropts, 'M'); *p = '\0'; }
-		if (Hooks[HOOKTYPE_USERMSG] && !strchr(serveropts, 'm'))
-			*p++ = 'm';
-		if (Hooks[HOOKTYPE_CHANMSG] && !strchr(serveropts, 'M'))
-			*p++ = 'M';
-		*p = '\0';
-		for (mi = Modules; mi; mi = mi->next)
-			if (!(mi->options & MOD_OPT_OFFICIAL))
-				tainted = 99;
-	}
-
-	return;
-}
-
-void add_throttling_bucket(Client *client)
-{
-	int hash;
-	struct ThrottlingBucket *n;
-
-	n = safe_alloc(sizeof(struct ThrottlingBucket));
-	n->next = n->prev = NULL; 
-	safe_strdup(n->ip, client->ip);
-	n->since = TStime();
-	n->count = 1;
-	hash = hash_throttling(client->ip);
-	AddListItem(n, ThrottlingHash[hash]);
-	return;
-}
-
-/** Checks whether the user is connect-flooding.
- * @retval 0 Denied, throttled.
- * @retval 1 Allowed, but known in the list.
- * @retval 2 Allowed, not in list or is an exception.
- * @see add_connection()
- */
-int throttle_can_connect(Client *client)
-{
-	struct ThrottlingBucket *b;
-
-	if (!THROTTLING_PERIOD || !THROTTLING_COUNT)
-		return 2;
-
-	if (!(b = find_throttling_bucket(client)))
-		return 1;
-	else
-	{
-		if (find_tkl_exception(TKL_CONNECT_FLOOD, client))
-			return 2;
-		if (b->count+1 > (THROTTLING_COUNT ? THROTTLING_COUNT : 3))
-			return 0;
-		b->count++;
-		return 2;
-	}
-}
-
-/**** IP users hash table *****/
-
-MODVAR IpUsersBucket *IpUsersHash_ipv4[IPUSERS_HASH_TABLE_SIZE];
-MODVAR IpUsersBucket *IpUsersHash_ipv6[IPUSERS_HASH_TABLE_SIZE];
-
-uint64_t hash_ipusers(const char *ip)
-{
-	return siphash(ip, siphashkey_ipusers) % IPUSERS_HASH_TABLE_SIZE;
-}
-
-IpUsersBucket *find_ipusers_bucket(Client *client)
-{
-	int hash = 0;
-	IpUsersBucket *p;
-	struct sockaddr *addr;
-
-	addr = raw_client_ip(client);
-	hash = hash_ipusers(client->ip);
-
-	if (addr->sa_family == AF_INET6)
-	{
-		for (p = IpUsersHash_ipv6[hash]; p; p = p->next)
-			if (memcmp(p->rawip, &((struct sockaddr_in6 *)addr)->sin6_addr.s6_addr, 16) == 0)
-				return p;
-	} else {
-		for (p = IpUsersHash_ipv4[hash]; p; p = p->next)
-			if (memcmp(p->rawip, &((struct sockaddr_in *)addr)->sin_addr.s_addr, 4) == 0)
-				return p;
-	}
-
-	return NULL;
-}
-
-IpUsersBucket *add_ipusers_bucket(Client *client)
-{
-	int hash;
-	IpUsersBucket *n;
-	struct sockaddr *addr;
-
-	addr = raw_client_ip(client);
-	hash = hash_ipusers(client->ip);
-
-	n = safe_alloc(sizeof(IpUsersBucket));
-	if (addr->sa_family == AF_INET6)
-	{
-		memcpy(n->rawip, &((struct sockaddr_in6 *)addr)->sin6_addr.s6_addr, 16);
-		AddListItem(n, IpUsersHash_ipv6[hash]);
-	} else {
-		memcpy(n->rawip, &((struct sockaddr_in *)addr)->sin_addr.s_addr, 4);
-		AddListItem(n, IpUsersHash_ipv4[hash]);
-	}
-	return n;
-}
-
-void decrease_ipusers_bucket(Client *client)
-{
-	int hash = 0;
-	IpUsersBucket *p;
-	struct sockaddr *addr;
-	char ipv6 = 0;
-
-	if (!(client->flags & CLIENT_FLAG_IPUSERS_BUMPED))
-		return; /* nothing to do */
-
-	client->flags &= ~CLIENT_FLAG_IPUSERS_BUMPED;
-
-	addr = raw_client_ip(client);
-	hash = hash_ipusers(client->ip);
-
-	ipv6 = addr->sa_family == AF_INET6 ? 1 : 0;
-
-	if (ipv6)
-	{
-		for (p = IpUsersHash_ipv6[hash]; p; p = p->next)
-			if (memcmp(p->rawip, &((struct sockaddr_in6 *)addr)->sin6_addr.s6_addr, 16) == 0)
-				break;
-	} else {
-		for (p = IpUsersHash_ipv4[hash]; p; p = p->next)
-			if (memcmp(p->rawip, &((struct sockaddr_in *)addr)->sin_addr.s_addr, 4) == 0)
-				break;
-	}
-
-	if (!p)
-	{
-		unreal_log(ULOG_INFO, "user", "BUG_DECREASE_IPUSERS_BUCKET", client,
-		           "[BUG] decrease_ipusers_bucket() called but bucket is gone for client $client.details");
-		return;
-	}
-
-	p->global_clients--;
-	if (MyConnect(client))
-		p->local_clients--;
-
-	if ((p->global_clients == 0) && (p->local_clients == 0))
-	{
-		if (ipv6)
-			DelListItem(p, IpUsersHash_ipv6[hash]);
-		else
-			DelListItem(p, IpUsersHash_ipv4[hash]);
-		safe_free(p);
-	}
-	return;
-}
