@@ -106,7 +106,7 @@ int match_tkls(Client *client)
 
 	if (loop.do_bancheck_spamf_away && IsUser(client) &&
 	    client->user->away != NULL &&
-	    match_spamfilter(client, client->user->away, SPAMF_AWAY, "AWAY", NULL, SPAMFLAG_NOWARN, NULL))
+	    match_spamfilter(client, client->user->away, SPAMF_AWAY, "AWAY", NULL, SPAMFLAG_NOWARN, NULL, NULL))
 	{
 		return 1;
 	}
@@ -288,8 +288,8 @@ static int bad_command(const char *argv0)
 	if (!argv0)
 		argv0 = "unrealircd";
 
-	printf("ERROR: Incorrect command line argument encountered.\n"
-	       "This is the unrealircd BINARY. End-users should NOT call this binary directly.\n"
+	printf("ERROR: Incorrect command line argument encountered (if you are looking for foreground mode, it is -F).\n"
+	       "IMPORTANT: This is the unrealircd BINARY. End-users should NOT call this binary directly.\n"
 	       "Please run the SCRIPT instead: %s/unrealircd\n", SCRIPTDIR);
 	printf("Server not started\n\n");
 #else
@@ -319,7 +319,6 @@ void fix_timers(void)
 	int i, cnt;
 	Client *client;
 	Event *e;
-	struct ThrottlingBucket *thr;
 	ConfigItem_link *lnk;
 
 	list_for_each_entry(client, &lclient_list, lclient_node)
@@ -349,22 +348,6 @@ void fix_timers(void)
 		}
 	}
 
-	/* For throttling we only have to deal with time jumping backward, which
-	 * is a real problem as if the jump was, say, 900 seconds, then it would
-	 * (potentially) throttle for 900 seconds.
-	 * Time going forward is "no problem", it just means we expire our entries
-	 * sonner than we should.
-	 */
-	cnt = 0;
-	for (i = 0; i < THROTTLING_HASH_TABLE_SIZE; i++)
-	{
-		for (thr = ThrottlingHash[i]; thr; thr = thr->next)
-		{
-			if (thr->since > TStime())
-				thr->since = TStime();
-		}
-	}
-
 	/* Make sure autoconnect for servers still works (lnk->hold) */
 	for (lnk = conf_link; lnk; lnk = lnk->next)
 	{
@@ -375,6 +358,8 @@ void fix_timers(void)
 			lnk->hold = TStime() + (t / 2); /* compromise */
 		}
 	}
+
+	// FIXME: add some hook call here!!
 }
 
 
@@ -513,7 +498,6 @@ void SetupEvents(void)
 	EventAdd(NULL, "handshake_timeout", handshake_timeout, NULL, 1000, 0);
 	EventAdd(NULL, "tls_check_expiry", tls_check_expiry, NULL, (86400/2)*1000, 0);
 	EventAdd(NULL, "unrealdb_expire_secret_cache", unrealdb_expire_secret_cache, NULL, 61000, 0);
-	EventAdd(NULL, "throttling_check_expire", throttling_check_expire, NULL, 1000, 0);
 	EventAdd(NULL, "memory_log_cleaner", memory_log_cleaner, NULL, 61500, 0);
 	EventAdd(NULL, "detect_high_connection_rate", detect_high_connection_rate, NULL, 1000*DETECT_HIGH_CONNECTION_RATE_SAMPLE_TIME, 0);
 	EventAdd(NULL, "central_spamfilter_download_evt", central_spamfilter_download_evt, NULL, 5000, 0);
@@ -785,7 +769,12 @@ int InitUnrealIRCd(int argc, char *argv[])
 	fprintf(stderr, "UnrealIRCd is brought to you by Bram Matthys (Syzop),\n"
 	                "Krzysztof Beresztant (k4be), Gottem and i\n\n");
 
-	fprintf(stderr, "Using the following libraries:\n");
+	fprintf(stderr, "UnrealIRCd is free and Open Source software. "
+	                "If you can, consider making a donation at "
+	                "https://www.unrealircd.org/index/donations "
+	                "to support us.\n\n");
+
+	fprintf(stderr, "UnrealIRCd is using the following libraries:\n");
 	fprintf(stderr, "* %s\n", SSLeay_version(SSLEAY_VERSION));
 	fprintf(stderr, "* libsodium %s\n", sodium_version_string());
 #ifdef USE_LIBCURL
@@ -824,7 +813,6 @@ int InitUnrealIRCd(int argc, char *argv[])
 	default_class->sendq = DEFAULT_RECVQ;
 	default_class->name = "default";
 	AddListItem(default_class, conf_class);
-	free_config_defines();
 	if (config_read_start() < 0)
 		exit(-1);
 	while (!is_config_read_finished())
@@ -851,14 +839,6 @@ int InitUnrealIRCd(int argc, char *argv[])
 		exit(-4);
 	}
 
-	if (!init_tls())
-	{
-		config_error("Failed to load TLS (see errors above). UnrealIRCd can not start.");
-#ifdef _WIN32
-		win_error(); /* display error dialog box */
-#endif
-		exit(9);
-	}
 	if (loop.config_test)
 	{
 		unreal_log(ULOG_INFO, "config", "CONFIG_PASSED", NULL, "Configuration test passed OK");
@@ -868,7 +848,6 @@ int InitUnrealIRCd(int argc, char *argv[])
 	if (loop.boot_function)
 		loop.boot_function();
 	open_debugfile();
-	me.local->port = 6667; /* pointless? */
 	applymeblock();
 #ifdef HAVE_SYSLOG
 	openlog("ircd", LOG_PID | LOG_NDELAY, LOG_DAEMON);
@@ -926,7 +905,8 @@ int InitUnrealIRCd(int argc, char *argv[])
 #endif
 
 	fix_timers();
-	write_pidfile();
+	if (!(bootopt & BOOT_NOFORK))
+		write_pidfile();
 	loop.booted = 1;
 #if defined(HAVE_SETPROCTITLE)
 	setproctitle("%s", me.name);
@@ -1023,7 +1003,6 @@ static void open_debugfile(void)
 		client = make_client(NULL, NULL);
 		client->local->fd = 2;
 		SetLog(client);
-		client->local->port = debuglevel;
 		client->flags = 0;
 
 		strlcpy(client->local->sockhost, me.local->sockhost, sizeof client->local->sockhost);
