@@ -145,6 +145,7 @@ static int crule_match_asn(crule_context *, int, void **);
 static int crule_match_certfp(crule_context *, int, void **);
 static int crule_match_realname(crule_context *, int, void **);
 static int crule_unicode_count(crule_context *, int, void **);
+static int crule_server_port(crule_context *, int, void **);
 
 /* parsing function prototypes - local! */
 static int crule_gettoken(crule_token *next_tokp, const char **str);
@@ -206,6 +207,7 @@ struct crule_funclistent crule_funclist[] = {
 	{"match_certfp", 1, crule_match_certfp},
 	{"match_realname", 1, crule_match_realname},
 	{"unicode_count", 1, crule_unicode_count},
+	{"server_port", 0, crule_server_port},
 	{"", 0, NULL} /* this must be here to mark end of list */
 };
 
@@ -566,6 +568,14 @@ static int crule_unicode_count(crule_context *context, int numargs, void *crulea
 	return 0;
 }
 
+static int crule_server_port(crule_context *context, int numargs, void *crulearg[])
+{
+	if (context && context->client)
+		return get_server_port(context->client);
+
+	return 0;
+}
+
 /** Evaluate a connection rule.
  * @param[in] rule Rule to evalute.
  * @return Non-zero if the rule allows the connection, zero otherwise.
