@@ -451,7 +451,7 @@ static void exit_one_client(Client *client, MessageTag *mtags_i, const char *com
 		free_message_tags(mtags_o);
 
 		while ((mp = client->user->channel))
-			remove_user_from_channel(client, mp->channel, 1);
+			remove_user_from_channel_withmb(client, mp->channel, mp, 1);
 		/* again, this is all that is needed */
 
 		/* For remote clients, we need to check for any outstanding async
